@@ -4,7 +4,7 @@ from ts3audiobot_api.commands import Playlist, History, User
 
 
 def format_url(url):
-    return urllib.parse.quote(str(url), safe='')
+    return urllib.parse.quote(str(url))
 
 
 class CommandCaller:
